API reference
=============


wiggelen
--------

.. automodule:: wiggelen
   :members: ParseError, ReadError, walk, zip_, fill, write


wiggelen.merge
--------------

.. automodule:: wiggelen.merge
   :members:


wiggelen.distance
-----------------

.. automodule:: wiggelen.distance
   :members:


wiggelen.transform
------------------

.. automodule:: wiggelen.transform
   :members:


wiggelen.intervals
------------------

.. automodule:: wiggelen.intervals
   :members:


wiggelen.index
--------------

.. automodule:: wiggelen.index
   :members:
   :exclude-members: ReadError
